==> haskell-megaparsec-5.3.1-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: megaparsec
version: 5.3.1
id: megaparsec-5.3.1-GxZCUFyxxwCHfCqiAPkdT1
key: megaparsec-5.3.1-GxZCUFyxxwCHfCqiAPkdT1
license: BSD2
maintainer: Mark Karpov <markkarpov92@gmail.com>
homepage: https://github.com/mrkkrp/megaparsec
synopsis: Monadic parser combinators
description:
    This is industrial-strength monadic parser combinator library. Megaparsec
    is a fork of Parsec library originally written by Daan Leijen.
category: Parsing
author: Megaparsec contributors,
        Paolo Martini <paolo@nemail.it>,
        Daan Leijen <daan@microsoft.com>
exposed: True
exposed-modules:
    Text.Megaparsec Text.Megaparsec.ByteString
    Text.Megaparsec.ByteString.Lazy Text.Megaparsec.Char
    Text.Megaparsec.Combinator Text.Megaparsec.Error
    Text.Megaparsec.Expr Text.Megaparsec.Lexer Text.Megaparsec.Perm
    Text.Megaparsec.Pos Text.Megaparsec.Prim Text.Megaparsec.String
    Text.Megaparsec.Text Text.Megaparsec.Text.Lazy
abi: 065dd48d188a16b3322ba65ed594090c
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/megaparsec-5.3.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/megaparsec-5.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/megaparsec-5.3.1
hs-libraries: HSmegaparsec-5.3.1-GxZCUFyxxwCHfCqiAPkdT1
depends:
    QuickCheck-2.10.0.1-ALuGysu7txTB2VnkPyDuTq base-4.9.1.0
    bytestring-0.10.8.1 containers-0.5.7.1 deepseq-1.4.2.0
    exceptions-0.8.3-8AMTYj188ri8VOH6LXt0Fd
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    scientific-0.3.5.0-7hRLtQzMvnkCQbsJuyPHcq
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-megaparsec/html/megaparsec.haddock
haddock-html: /usr/share/doc/haskell-megaparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-megaparsec-5.3.1-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: megaparsec
version: 5.3.1
id: megaparsec-5.3.1-9NkUd2RGYlu1wtR645IhSo
key: megaparsec-5.3.1-9NkUd2RGYlu1wtR645IhSo
license: BSD2
maintainer: Mark Karpov <markkarpov92@gmail.com>
homepage: https://github.com/mrkkrp/megaparsec
synopsis: Monadic parser combinators
description:
    This is industrial-strength monadic parser combinator library. Megaparsec
    is a fork of Parsec library originally written by Daan Leijen.
category: Parsing
author: Megaparsec contributors,
        Paolo Martini <paolo@nemail.it>,
        Daan Leijen <daan@microsoft.com>
exposed: True
exposed-modules:
    Text.Megaparsec Text.Megaparsec.ByteString
    Text.Megaparsec.ByteString.Lazy Text.Megaparsec.Char
    Text.Megaparsec.Combinator Text.Megaparsec.Error
    Text.Megaparsec.Expr Text.Megaparsec.Lexer Text.Megaparsec.Perm
    Text.Megaparsec.Pos Text.Megaparsec.Prim Text.Megaparsec.String
    Text.Megaparsec.Text Text.Megaparsec.Text.Lazy
abi: b32028523f6b6bc3e0fbf460f9ac8ca6
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/megaparsec-5.3.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/megaparsec-5.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/megaparsec-5.3.1
hs-libraries: HSmegaparsec-5.3.1-9NkUd2RGYlu1wtR645IhSo
depends:
    QuickCheck-2.10.0.1-ALuGysu7txTB2VnkPyDuTq base-4.9.1.0
    bytestring-0.10.8.1 containers-0.5.7.1 deepseq-1.4.2.0
    exceptions-0.8.3-8AMTYj188ri8VOH6LXt0Fd
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    scientific-0.3.5.1-3aJEdQvcyho88FhIoGrzGS
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-megaparsec/html/megaparsec.haddock
haddock-html: /usr/share/doc/haskell-megaparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
